﻿using BuaaLocationServer.Dto;
using BuaaLocationServer.Middlewares.Db;
using BuaaLocationServer.Middlewares.Jwts;
using BuaaLocationServer.Models;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Caching.Memory;
using System.ComponentModel.DataAnnotations;

namespace BuaaLocationServer.Controllers
{

    /// <summary>
    /// 公司信息
    /// </summary>
    [ApiController]
    [Authorize]
    [Route("api/[controller]")]
    public class CompaniesController:BaseController
    {
        private readonly BuaaDbContext _context;
        private readonly ILogger<AuthenticationController> _logger;
        private readonly IMemoryCache _memoryCache;
        private readonly IJwtService _jwtService;

        public CompaniesController(
            ILogger<AuthenticationController> logger,
            BuaaDbContext context,
            IMemoryCache memoryCache,
            IJwtService jwtService)
        {
            _logger = logger;
            _context = context;
            _memoryCache = memoryCache;
            _jwtService = jwtService;
        }

        /// <summary>
        /// 获取公司信息
        /// </summary>
        /// <param name="name">公司名称</param>
        /// <returns></returns>
        [HttpGet]
        public async Task<ActionResult<CompanyDto>> Get([FromQuery,Required]string name)
        {
            var company = await _context.Companies.FirstOrDefaultAsync(e => e.Name == name);
            if (company == null)
            {
                return NotFound();
            }
            var dto = new CompanyDto()
            {
                Name = company.Name,
                Content = company.Content
            };
            return Ok(dto);
        }

        /// <summary>
        /// 创建或者更新
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost]
        public async Task<ActionResult<CompanyDto>> Create([FromBody,Required]CompanyDto dto)
        {
            if (string.IsNullOrEmpty(dto.Name))
            {
                return BadRequest($"{nameof(dto.Name)} 不能为空。");
            }
            var company = await _context.Companies.FirstOrDefaultAsync(e => e.Name == dto.Name);
            if (company == null)
            {
                company = new Company();
                company.Name = dto.Name;
                await _context.Companies.AddAsync(company);
            }
            company.Content = dto.Content;
            await _context.SaveChangesAsync();
            return Ok(dto);
        }
    }
}
